@@ -136,6 +136,7 @@ class OpenEVSE:
                         _LOGGER.warning("Non JSON response: %s", message)
 
                     if resp.status == 400:
+                        index = ""
                         if "msg" in message.keys():
                             index = "msg"
                         elif "error" in message.keys():
@@ -894,11 +895,18 @@ class OpenEVSE:
 
     @property
     def max_current_soft(self) -> int | None:
-        """Return the firmware version."""
+        """Return the max current soft."""
         if self._config is not None and "max_current_soft" in self._config:
             return self._config["max_current_soft"]
         return self._status["pilot"]
 
+    @property
+    def max_current(self) -> int | None:
+        """Return the max current."""
+        if self._status is not None and "max_current" in self._status:
+            return self._status["max_current"]
+        return None
+
     @property
     def wifi_firmware(self) -> str:
         """Return the ESP firmware version."""
@@ -1234,6 +1242,8 @@ class OpenEVSE:
         """Return battery level."""
         if self._status is not None and "vehicle_soc" in self._status:
             return self._status["vehicle_soc"]
+        if self._status is not None and "battery_level" in self._status:
+            return self._status["battery_level"]
         return None
 
     @property
@@ -1241,6 +1251,8 @@ class OpenEVSE:
         """Return battery range."""
         if self._status is not None and "vehicle_range" in self._status:
             return self._status["vehicle_range"]
+        if self._status is not None and "battery_range" in self._status:
+            return self._status["battery_range"]
         return None
 
     @property
@@ -1248,6 +1260,8 @@ class OpenEVSE:
         """Return time to full charge."""
         if self._status is not None and "vehicle_eta" in self._status:
             return self._status["vehicle_eta"]
+        if self._status is not None and "time_to_full_charge" in self._status:
+            return self._status["time_to_full_charge"]
         return None
 
     # There is currently no min/max amps JSON data
